""" a cli aligner based mdx dictionary.

currently only en-zh based on msbing mdx
"""
# __date__ = "2020.8.12"
__version__ = "0.1.2"
VERSION = __version__.split(".")
